@@ -1,3 +1,3 @@
 from tracktime.synchronisers.base import Synchroniser
 
-__all__ = (Synchroniser)
+__all__ = ("Synchroniser",)
