@@ -13,6 +13,7 @@ from tracktime.synchronisers.base import AggregatedTime, ExternalSynchroniser
 
 
 class GitLabSynchroniser(ExternalSynchroniser):
+    name = "GitLab"
     types = ("gl", "gitlab")
     task_types = {"#": "issue", "!": "merge_request"}
 
@@ -26,9 +27,6 @@ class GitLabSynchroniser(ExternalSynchroniser):
         path = parse.urljoin(self.api_root, rel_path)
         return requester(path, {"private_token": self.api_key, **params})
 
-    def get_name(self):
-        return "GitLab"
-
     def sync(
         self,
         aggregated_time: AggregatedTime,
